pub enum ReferencingError {
Unretrievable {
uri: String,
source: Box<dyn Error + Send + Sync>,
},
PointerToNowhere {
pointer: String,
},
InvalidPercentEncoding {
pointer: String,
source: Utf8Error,
},
InvalidArrayIndex {
pointer: String,
index: String,
source: ParseIntError,
},
NoSuchAnchor {
anchor: String,
},
InvalidAnchor {
anchor: String,
},
InvalidUri(UriError),
UnknownSpecification {
specification: String,
},
CircularMetaschema {
uri: String,
},
}Expand description
Errors that can occur during reference resolution and resource handling.
Variants
Unretrievable
A resource is not present in a registry and retrieving it failed.
PointerToNowhere
A JSON Pointer leads to a part of a document that does not exist.
InvalidPercentEncoding
JSON Pointer contains invalid percent-encoded data.
InvalidArrayIndex
Failed to parse array index in JSON Pointer.
NoSuchAnchor
An anchor does not exist within a particular resource.
InvalidAnchor
An anchor which could never exist in a resource was dereferenced.
InvalidUri(UriError)
An error occurred while parsing or manipulating a URI.
UnknownSpecification
An unknown JSON Schema specification was encountered.
CircularMetaschema
A circular reference was detected in a meta-schema chain.
Implementations