pub struct MetaSchemaOptions<'a> { /* private fields */ }Expand description
Options for meta-schema validation.
Implementations
Sourceimpl<'a> MetaSchemaOptions<'a>
impl<'a> MetaSchemaOptions<'a>
Sourcepub fn with_registry(self, registry: &'a Registry<'a>) -> Self
pub fn with_registry(self, registry: &'a Registry<'a>) -> Self
Use a registry for resolving custom meta-schemas.
Examples
use serde_json::json;
use jsonschema::{Registry, Resource};
let custom_meta = Resource::from_contents(json!({
"$schema": "https://json-schema.org/draft/2020-12/schema",
"type": "object"
}));
let registry = Registry::new()
.add("http://example.com/meta", custom_meta)
.unwrap()
.prepare()
.unwrap();
let options = jsonschema::meta::options()
.with_registry(®istry);Sourcepub fn is_valid(&self, schema: &Value) -> bool
pub fn is_valid(&self, schema: &Value) -> bool
Check if a schema is valid according to its meta-schema.
Panics
Panics if the meta-schema cannot be resolved.
Sourcepub fn validate<'schema>(
&self,
schema: &'schema Value,
) -> Result<(), ValidationError<'schema>>
pub fn validate<'schema>( &self, schema: &'schema Value, ) -> Result<(), ValidationError<'schema>>
Validate a schema according to its meta-schema.
Errors
Returns ValidationError if the schema is invalid or if the meta-schema cannot be resolved.