JsonTypeSet

Struct JsonTypeSet 

pub struct JsonTypeSet(/* private fields */);
A set of JSON types.

Implementations

Source

impl JsonTypeSet

pub const fn empty() -> JsonTypeSet

Create an empty set of types.

pub const fn all() -> JsonTypeSet

Create a set with all possible JSON types.

pub const fn insert(self, ty: JsonType) -> JsonTypeSet

Add a type to this set and return the modified set.

pub const fn remove(self, ty: JsonType) -> JsonTypeSet

Remove a type from this set and return the modified set.

pub const fn intersect(self, other: JsonTypeSet) -> JsonTypeSet

Types in both sets.

pub const fn union(self, other: JsonTypeSet) -> JsonTypeSet

Types in either set.

pub const fn len(self) -> usize

Return the number of types in this set.

pub const fn is_empty(self) -> bool

Return true if the set contains no types.

pub fn contains(self, ty: JsonType) -> bool

Check if this set includes the specified type.

pub fn contains_value_type<F>(self, value: &<F as Json>::Node<'_>) -> bool
where F: Json,

Whether a JSON value’s type is allowed by this set.

pub fn iter(&self) -> JsonTypeSetIterator

Get an iterator over the types in this set.