pub struct MetaSchemaOptions { /* private fields */ }Expand description
Options for meta-schema validation.
Implementations
Sourceimpl MetaSchemaOptions
impl MetaSchemaOptions
Sourcepub fn with_registry(self, registry: Registry) -> Self
pub fn with_registry(self, registry: Registry) -> Self
Use a registry for resolving custom meta-schemas.
Examples
use serde_json::json;
use jsonschema::{Registry, Resource};
let custom_meta = Resource::from_contents(json!({
"$schema": "https://json-schema.org/draft/2020-12/schema",
"type": "object"
}));
let registry = Registry::try_new(
"http://example.com/meta",
custom_meta
).unwrap();
let options = jsonschema::meta::options()
.with_registry(registry);Sourcepub fn is_valid(&self, schema: &Value) -> bool
pub fn is_valid(&self, schema: &Value) -> bool
Check if a schema is valid according to its meta-schema.
Panics
Panics if the meta-schema cannot be resolved.
Sourcepub fn validate<'a>(&self, schema: &'a Value) -> Result<(), ValidationError<'a>>
pub fn validate<'a>(&self, schema: &'a Value) -> Result<(), ValidationError<'a>>
Validate a schema according to its meta-schema.
Errors
Returns ValidationError if the schema is invalid or if the meta-schema cannot be resolved.