Struct jsonschema::output::OutputUnit
source · pub struct OutputUnit<T> { /* private fields */ }Expand description
An output unit is a reference to a place in a schema and a place in an
instance along with some value associated to that place. For annotations the
value will be an Annotations and for errors it will be an
ErrorDescription. See the documentation for Output::basic for a
detailed example.
Implementations
sourceimpl<T> OutputUnit<T>
impl<T> OutputUnit<T>
sourcepub const fn keyword_location(&self) -> &JSONPointer
pub const fn keyword_location(&self) -> &JSONPointer
The location in the schema of the keyword
sourcepub const fn absolute_keyword_location(&self) -> &Option<AbsolutePath>
pub const fn absolute_keyword_location(&self) -> &Option<AbsolutePath>
The absolute location in the schema of the keyword. This will be
different to keyword_location if the schema is a resolved reference.
sourcepub const fn instance_location(&self) -> &JSONPointer
pub const fn instance_location(&self) -> &JSONPointer
The location in the instance
sourceimpl OutputUnit<Annotations<'_>>
impl OutputUnit<Annotations<'_>>
sourceimpl OutputUnit<ErrorDescription>
impl OutputUnit<ErrorDescription>
sourcepub const fn error_description(&self) -> &ErrorDescription
pub const fn error_description(&self) -> &ErrorDescription
The error for this output unit