pub struct JsonTypeSet(/* private fields */);Expand description
A set of JSON types.
Implementations
Sourceimpl JsonTypeSet
impl JsonTypeSet
Sourcepub const fn empty() -> JsonTypeSet
pub const fn empty() -> JsonTypeSet
Create an empty set of types.
Sourcepub const fn all() -> JsonTypeSet
pub const fn all() -> JsonTypeSet
Create a set with all possible JSON types.
Sourcepub const fn insert(self, ty: JsonType) -> JsonTypeSet
pub const fn insert(self, ty: JsonType) -> JsonTypeSet
Add a type to this set and return the modified set.
Sourcepub const fn remove(self, ty: JsonType) -> JsonTypeSet
pub const fn remove(self, ty: JsonType) -> JsonTypeSet
Remove a type from this set and return the modified set.
Sourcepub const fn intersect(self, other: JsonTypeSet) -> JsonTypeSet
pub const fn intersect(self, other: JsonTypeSet) -> JsonTypeSet
Types in both sets.
Sourcepub const fn union(self, other: JsonTypeSet) -> JsonTypeSet
pub const fn union(self, other: JsonTypeSet) -> JsonTypeSet
Types in either set.
Sourcepub fn contains_value_type<F>(self, value: &<F as Json>::Node<'_>) -> boolwhere
F: Json,
pub fn contains_value_type<F>(self, value: &<F as Json>::Node<'_>) -> boolwhere
F: Json,
Whether a JSON value’s type is allowed by this set.
Sourcepub fn iter(&self) -> JsonTypeSetIterator ⓘ
pub fn iter(&self) -> JsonTypeSetIterator ⓘ
Get an iterator over the types in this set.